@@ -9,20 +9,12 @@ import psutil
 
 HEADERS = {"Content-Type": "application/json"}
 STAT_ENDPOINT = "https://api.statcord.com/v3/stats"
-CLUSTERS_ENDPOINT = "https://api.statcord.com/v3/clusters"
 
 
 class StatcordClient:
     """The base Statcord client class."""
 
-    def __init__(
-        self,
-        bot: commands.Bot,
-        statcord_key: str,
-        custom_1: Callable = None,
-        custom_2: Callable = None,
-        cluster_id: str = None,
-    ) -> None:
+    def __init__(self, bot: commands.Bot, statcord_key: str, custom_1: Callable = None, custom_2: Callable = None) -> None:
         self.bot = bot
 
         self.statcord_key = statcord_key
@@ -30,8 +22,6 @@ class StatcordClient:
         self.custom_1 = custom_1
         self.custom_2 = custom_2
 
-        self.cluster_id = cluster_id
-
         # validate args
         if not isinstance(bot, commands.Bot):
             raise TypeError("The bot argument must be or be a subclass of discord.ext.commands.Bot")
